@@ -24,7 +24,7 @@ use serde::{
     de::{self, Unexpected},
     Deserialize, Deserializer, Serialize,
 };
-use serde_with::{serde_as, DurationMilliSeconds, DurationSeconds};
+use serde_with::{serde_as, DurationMilliSeconds, DurationSeconds, TimestampSecondsWithFrac};
 use std::{error::Error, fmt, num::ParseIntError, str::FromStr};
 
 /// Represents a parsing error.
@@ -233,9 +233,11 @@ pub enum NavMode {
 #[derive(Serialize, Deserialize, Debug, PartialEq, Clone)]
 pub struct AgedPosition {
     #[serde_as(as = "DurationSeconds<f64>")]
-    pub age: std::time::Duration,
+    pub seen_pos: std::time::Duration,
     pub lat: f64,
     pub lon: f64,
+    pub nic: u8,
+    pub rc: u16,
 }
 
 // "ARA": "1100001",
@@ -292,7 +294,7 @@ pub struct Aircraft {
     pub aircraft_type: Option<String>,
 
     #[serde(rename = "baro_rate")]
-    pub barometric_vertical_rate: Option<i16>,
+    pub barometric_vertical_rate: Option<i32>,
 
     #[serde(rename = "alt_baro")]
     pub barometric_altitude: Option<AltitudeOrGround>,
@@ -326,6 +328,11 @@ pub struct Aircraft {
     #[serde(rename = "geom_rate")]
     pub geometric_vertical_rate: Option<i16>,
 
+    #[serde_as(as = "Option<TimestampSecondsWithFrac<f64>>")]
+    #[serde(default)]
+    #[serde(rename = "gpsOkBefore")]
+    pub gps_ok_before: Option<DateTime<Utc>>,
+
     #[serde(rename = "gs")]
     pub ground_speed_knots: Option<f32>,
 
@@ -513,14 +520,17 @@ mod tests {
                    "emergency": "none",
                    "flight": "N1234",
                    "geom_rate": 1000,
+                   "gpsOkBefore": 1631836547.1,
                    "gs": 50,
                    "gva": 1,
                    "hex":"000000",
                    "ias": 45.1,
                    "lastPosition": {
-                       "age": 120.4,
+                       "seen_pos": 120.4,
                        "lat": 4.0,
-                       "lon": 4.1
+                       "lon": 4.1,
+                       "rc": 186,
+                       "nic": 8
                    },
                    "lat": 1.1,
                    "lon": 1.2,
@@ -584,14 +594,17 @@ mod tests {
                     geometric_altitude: Some(123),
                     geometric_vertical_accuracy: Some(1),
                     geometric_vertical_rate: Some(1000),
+                    gps_ok_before: Some(Utc.ymd(2021, 9, 16).and_hms_milli(23, 55, 47, 100)),
                     ground_speed_knots: Some(50.0),
                     hex: "000000".to_string(),
                     indicated_air_speed_knots: Some(45.1),
                     is_alert: Some(true),
                     last_position: Some(AgedPosition {
-                        age: std::time::Duration::new(120, 0),
+                        seen_pos: std::time::Duration::new(120, 0),
                         lat: 4.0,
                         lon: 4.1,
+                        nic: 8,
+                        rc: 186,
                     }),
                     lat: Some(1.1),
                     lon: Some(1.2),
